# Generated by Django 2.1.9 on 2019-06-26 21:17

import django.contrib.gis.db.models.fields
import django.core.files.storage
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("core", "0004_auto_20171005_2028"),
        ("councilmatic_core", "0047_update_filepath"),
    ]

    operations = [
        migrations.DeleteModel(
            name="Post",
        ),
        migrations.CreateModel(
            name="Post",
            fields=[
                (
                    "post",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        related_name="councilmatic_post",
                        serialize=False,
                        to="core.Post",
                    ),
                ),
                (
                    "shape",
                    django.contrib.gis.db.models.fields.GeometryField(
                        null=True, srid=4326
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
            bases=("core.post",),
        ),
    ]
